unit UnitMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  CWindowThread, StdCtrls, ExtCtrls, ComCtrls, ExtDlgs, Spin, CSplashWindow;

type
  TForm1 = class(TForm)
    cbVisible: TCheckBox;
    cbAlphaShow: TCheckBox;
    cbUseSysFont: TCheckBox;
    CWindowThread1: TCWindowThread;
    cbEnabled: TCheckBox;
    cbCanceled: TCheckBox;
    Timer1: TTimer;
    ColorDialog1: TColorDialog;
    pColor: TPanel;
    ColorDialog2: TColorDialog;
    pCaptionColor: TPanel;
    eCaption: TEdit;
    mText: TMemo;
    TrackBar1: TTrackBar;
    lPercent: TLabel;
    lIconSize: TLabel;
    TrackBar2: TTrackBar;
    ComboBox1: TComboBox;
    lIconResourceName: TLabel;
    bIcon: TButton;
    OpenPictureDialog1: TOpenPictureDialog;
    FontDialog1: TFontDialog;
    bFontCap: TButton;
    bFont: TButton;
    FontDialog2: TFontDialog;
    seTotalTimeSec: TSpinEdit;
    bStartTime: TButton;
    lTotalTimeSec: TLabel;
    bTimerFont: TButton;
    FontDialog3: TFontDialog;
    cbCtl3d: TCheckBox;
    lInterval: TLabel;
    tbInterval: TTrackBar;
    ComboBox2: TComboBox;
    lPosition: TLabel;
    tbWidth: TTrackBar;
    tbHeight: TTrackBar;
    Label1: TLabel;
    Label2: TLabel;
    StatusBar1: TStatusBar;
    procedure FormShow(Sender: TObject);
    procedure cbVisibleClick(Sender: TObject);
    procedure cbAlphaShowClick(Sender: TObject);
    procedure cbUseSysFontClick(Sender: TObject);
    procedure cbEnabledClick(Sender: TObject);
    procedure cbCanceledClick(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure pColorClick(Sender: TObject);
    procedure pCaptionColorClick(Sender: TObject);
    procedure eCaptionChange(Sender: TObject);
    procedure mTextChange(Sender: TObject);
    procedure TrackBar1Change(Sender: TObject);
    procedure TrackBar2Change(Sender: TObject);
    procedure ComboBox1Change(Sender: TObject);
    procedure bIconClick(Sender: TObject);
    procedure bFontCapClick(Sender: TObject);
    procedure bFontClick(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure seTotalTimeSecChange(Sender: TObject);
    procedure bStartTimeClick(Sender: TObject);
    procedure bTimerFontClick(Sender: TObject);
    procedure cbCtl3dClick(Sender: TObject);
    procedure tbIntervalChange(Sender: TObject);
    procedure ComboBox2Change(Sender: TObject);
    procedure tbWidthChange(Sender: TObject);
    procedure tbHeightChange(Sender: TObject);
  private
    procedure UpdateControls;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
{$R SPLASH.RES}

function EnumResNameProc(Module: hModule;
                         lpszType: PChar;
                         lpszName: PChar;
                         lParam: Pointer):BOOL; stdcall;
var List: TStringList;
begin
  if (lParam<>nil) and (TObject(LParam) is TStringList) then
  begin
    List := TStringList(lParam);
    if Integer(lpszName)>High(Word) then
      List.Add(lpszName)
    else
    begin
      List.Add('#'+Inttostr(integer(lpszName)));
    end;
  end;
  result := true;
end;

procedure EnumResources(List: TStringList);
var L:TStringList;
    i:integer;
begin
  if List = nil then Exit;       
  L := nil;
  try
    if List<>nil then
    begin
      L := TStringList.Create;
      EnumResourceNames(hInstance, RT_GROUP_ICON, @EnumResNameProc, integer(L));
      List.BeginUpdate;
      try
        for i := 0 to L.Count-1 do
          if List.IndexOf(L[i])=-1 then List.Add(L[I]);
      finally
        List.EndUpdate;
      end;
    end;
  finally
    FreeAndNil(L);
  end;
end;


procedure TForm1.UpdateControls;
var R: TRect;
begin
  cbVisible.Checked := CWindowThread1.Visible;
  cbAlphaShow.Checked := CWindowThread1.AlphaShow;
  cbUseSysFont.Checked := CWindowThread1.UseSysFont;
  cbEnabled.Checked := CWindowThread1.Enabled;
  cbCanceled.Checked := CWindowThread1.Canceled;
  pColor.Color := CWindowThread1.Color;
  pCaptionColor.Color := CWindowThread1.CaptionColor;
  eCaption.Text := CWindowThread1.Caption;
  mText.Text := CWindowThread1.Text;
  lPercent.Caption := 'Percent: ' + inttostr(CWindowThread1.Percent);
  TrackBar1.Position := CWindowThread1.Percent;
  lIconSize.Caption := 'IconSize: ' + inttostr(CWindowThread1.IconSize);
  TrackBar2.Position := CWindowThread1.IconSize;
  ComboBox1.Text := CWindowThread1.IconResourceName;
  R := Rect(8, bIcon.Top-1, 56, bIcon.Top + 48);
  InvalidateRect(Handle, @R, False);
  seTotalTimeSec.Value := CWindowThread1.TotalTimeSec;
  cbCtl3d.Checked := CWindowThread1.Ctl3d;
  lInterval.Caption := 'Interval: ' + inttostr(CWindowThread1.Interval);
  tbInterval.Position := CWindowThread1.Interval;
  if (CWindowThread1.Visible) or (ComboBox2.ItemIndex = -1) then
    ComboBox2.ItemIndex := Integer(CWindowThread1.Position);
  ComboBox2.Enabled := not CWindowThread1.Visible;
  tbWidth.Position := CWindowThread1.Width;
  tbHeight.Position := CWindowThread1.Height;
end;

procedure TForm1.FormShow(Sender: TObject);
var List: TStringList;
begin
  ComboBox1.OnChange := nil;
  ComboBox1.Clear;
  List := TStringList.Create;
  try
    EnumResources(List);
    ComboBox1.Items.Assign(List);
  finally
    FreeAndNil(List);
    ComboBox1.OnChange := ComboBox1Change;
  end;
  tbWidth.Max := Screen.Width;
  tbHeight.Max := Screen.Height;
  UpdateControls;
end;

procedure TForm1.cbVisibleClick(Sender: TObject);
var R: TRect;
begin
  if (cbVisible.Checked) and
     (CWindowThread1.Position = pwtDesigned) then
  begin
    R.TopLeft := ClientToScreen(Point(0,0));
    R.Bottom := R.Top + tbHeight.Position;
    R.Right := R.Left + tbWidth.Position;
    CWindowThread1.BoundsRect := R;
  end;
  CWindowThread1.Visible := cbVisible.Checked;
end;

procedure TForm1.cbAlphaShowClick(Sender: TObject);
begin
  CWindowThread1.AlphaShow := cbAlphaShow.Checked;
end;

procedure TForm1.cbUseSysFontClick(Sender: TObject);
begin
  CWindowThread1.UseSysFont := cbUseSysFont.Checked;
end;

procedure TForm1.cbEnabledClick(Sender: TObject);
begin
  CWindowThread1.Enabled := cbEnabled.Checked;
end;

procedure TForm1.cbCanceledClick(Sender: TObject);
begin
  CWindowThread1.Canceled := cbCanceled.Checked;
end;

procedure TForm1.Timer1Timer(Sender: TObject);
begin
  UpdateControls;
end;

procedure TForm1.pColorClick(Sender: TObject);
begin
  ColorDialog1.Color := CWindowThread1.Color;
  if ColorDialog1.Execute then
    CWindowThread1.Color := ColorDialog1.Color;
end;

procedure TForm1.pCaptionColorClick(Sender: TObject);
begin
  ColorDialog2.Color := CWindowThread1.CaptionColor;
  if ColorDialog2.Execute then
    CWindowThread1.CaptionColor := ColorDialog2.Color;
end;

procedure TForm1.eCaptionChange(Sender: TObject);
begin
  CWindowThread1.Caption := eCaption.Text;
end;

procedure TForm1.mTextChange(Sender: TObject);
begin
  CWindowThread1.Text := mText.Text;
end;

procedure TForm1.TrackBar1Change(Sender: TObject);
begin
  CWindowThread1.Percent := TrackBar1.Position;
end;

procedure TForm1.TrackBar2Change(Sender: TObject);
begin
  CWindowThread1.IconSize := TrackBar2.Position;
end;

procedure TForm1.ComboBox1Change(Sender: TObject);
begin
  CWindowThread1.IconResourceName := ComboBox1.Text;
  Repaint;
end;

procedure TForm1.bIconClick(Sender: TObject);
var Icon: TIcon;
begin
  if OpenPictureDialog1.Execute then
  begin
    Icon := TIcon.Create;
    try
      Icon.Width := CWindowThread1.IconSize;
      Icon.Height := CWindowThread1.IconSize;
      Icon.LoadFromFile(OpenPictureDialog1.FileName);
      CWindowThread1.Icon := Icon;
    finally
      FreeAndNil(Icon);
    end;
  end;
  Repaint;
end;

procedure TForm1.bFontCapClick(Sender: TObject);
begin
  if CWindowThread1.CaptionFont <> nil then
    FontDialog1.Font := CWindowThread1.CaptionFont;
  if FontDialog1.Execute then
  begin
    CWindowThread1.CaptionFont := FontDialog1.Font;
  end;
end;

procedure TForm1.bFontClick(Sender: TObject);
begin
  if CWindowThread1.Font <> nil then
    FontDialog2.Font := CWindowThread1.Font;
  if FontDialog2.Execute then
  begin
    CWindowThread1.Font := FontDialog2.Font;
  end;
end;

procedure TForm1.bTimerFontClick(Sender: TObject);
begin
  if CWindowThread1.TimerFont <> nil then
    FontDialog3.Font := CWindowThread1.TimerFont;
  if FontDialog3.Execute then
  begin
    CWindowThread1.TimerFont := FontDialog3.Font;
  end;
end;

procedure TForm1.FormPaint(Sender: TObject);
begin
  Canvas.Brush.Color := Color;
  Canvas.FillRect(Rect(bIcon.Left - 70,bIcon.Top - 1, bIcon.Left, bIcon.Top + 70));
  if CWindowThread1.Icon <> nil then
    Canvas.Draw(bIcon.Left - 70,bIcon.Top - 1,CWindowThread1.Icon);
end;

procedure TForm1.seTotalTimeSecChange(Sender: TObject);
begin
  CWindowThread1.TotalTimeSec := seTotalTimeSec.Value;
end;

procedure TForm1.bStartTimeClick(Sender: TObject);
begin
  CWindowThread1.StartTime := Now;
end;

procedure TForm1.cbCtl3dClick(Sender: TObject);
begin
  CWindowThread1.Ctl3d := cbCtl3d.Checked;
end;

procedure TForm1.tbIntervalChange(Sender: TObject);
begin
  CWindowThread1.Interval := tbInterval.Position;
end;

procedure TForm1.ComboBox2Change(Sender: TObject);
begin
  CWindowThread1.Position := TPosWindowThread(ComboBox2.ItemIndex);
end;

procedure TForm1.tbWidthChange(Sender: TObject);
begin
  CWindowThread1.Width := tbWidth.Position;
end;

procedure TForm1.tbHeightChange(Sender: TObject);
begin
  CWindowThread1.Height := tbHeight.Position;
end;

end.
